'use strict';

var stringUtils = require('./stringUtils.js');
var customLayoutUtils = require('./customLayoutUtils.js');

function extractPivotSlotOptions(vnodes) {
    const options = {
        columns: [],
        columnHeaderTitle: [],
        rows: [],
        rowHeaderTitle: [],
        indicators: [],
        corner: {},
        tooltip: {},
        menu: {}
    };
    const typeMapping = {
        PivotColumnDimension: 'columns',
        PivotColumnHeaderTitle: 'columnHeaderTitle',
        PivotRowDimension: 'rows',
        PivotRowHeaderTitle: 'rowHeaderTitle',
        PivotCorner: 'corner',
        PivotIndicator: 'indicators',
        Tooltip: 'tooltip',
        Menu: 'menu'
    };
    vnodes.forEach(vnode => {
        var _a, _b;
        vnode.props = stringUtils.convertPropsToCamelCase(vnode.props);
        const typeName = ((_a = vnode.type) === null || _a === void 0 ? void 0 : _a.symbol) || ((_b = vnode.type) === null || _b === void 0 ? void 0 : _b.name);
        const optionKey = typeMapping[typeName];
        if (optionKey) {
            if (Array.isArray(options[optionKey])) {
                if (vnode.props.hasOwnProperty('objectHandler')) {
                    options[optionKey].push(vnode.props.objectHandler);
                }
                else {
                    options[optionKey].push(vnode.props);
                }
            }
            else {
                options[optionKey] = vnode.props;
            }
        }
    });
    return options;
}
function extractListSlotOptions(vnodes) {
    const options = {
        columns: [],
        tooltip: {},
        menu: {}
    };
    const typeMapping = {
        ListColumn: 'columns',
        Tooltip: 'tooltip',
        Menu: 'menu'
    };
    vnodes.forEach(vnode => {
        var _a, _b;
        vnode.props = stringUtils.convertPropsToCamelCase(vnode.props);
        const typeName = ((_a = vnode.type) === null || _a === void 0 ? void 0 : _a.symbol) || ((_b = vnode.type) === null || _b === void 0 ? void 0 : _b.name);
        const optionKey = typeMapping[typeName];
        if (optionKey) {
            if (optionKey === 'columns' && vnode.children) {
                vnode.props.customLayout = customLayoutUtils.createCustomLayoutHandler(vnode.children);
            }
            if (Array.isArray(options[optionKey])) {
                options[optionKey].push(vnode.props);
            }
            else {
                options[optionKey] = vnode.props;
            }
        }
    });
    return options;
}

exports.extractListSlotOptions = extractListSlotOptions;
exports.extractPivotSlotOptions = extractPivotSlotOptions;
